#!/bin/bash

tksuite_var_dir=/var/tksuite_server

echo "Creating $tksuite_var_dir hierarchie..."

if [ -d "$tksuite_var_dir" ]; then
    echo "skipping tksuite_server"
else
    mkdir $tksuite_var_dir
fi

if [ -d "$tksuite_var_dir/dbf" ]; then
    echo "skipping tksuite_server/dbf"
else
    mkdir $tksuite_var_dir/dbf
fi

if [ -d "$tksuite_var_dir/files" ]; then
    echo "skipping tksuite_server/files"
else
    mkdir $tksuite_var_dir/files
fi

if [ -d "$tksuite_var_dir/images" ]; then
    echo "skipping tksuite_server/images"
else
    mkdir $tksuite_var_dir/images
fi

if [ -d "$tksuite_var_dir/updates" ]; then
    echo "skipping tksuite_server/updates"
else
    mkdir $tksuite_var_dir/updates
fi

if [ -r "$tksuite_var_dir/tksock.ini" ]; then
    echo "skipping tksuite_server/tksock.ini"
else
    cat <<-EOF > $tksuite_var_dir/tksock.ini
	[path]
	files=$tksuite_var_dir/files
	dbf=$tksuite_var_dir/dbf
	[app]
	bill_n=1
	contact=1
	EOF
fi

# update.xml immer aktualisieren
#if [ -r "$tksuite_var_dir/update.xml" ]; then
#    echo "skipping tksuite_server/update.xml"
#else
    cp tksuite_server/update.xml.default $tksuite_var_dir/update.xml
#fi

# Prüfen, ob TK-Suite 3 Datenbanken vorhanden sind. Wenn ja,
# das var/dbf in var/dbf3 umbenennen und die Daten ins 4er Format
# konvertieren

tksuite_db_version_file=$tksuite_var_dir/schema_version.ini

if [ -f $tksuite_var_dir/dbf/contact.db ]
then

  tksuite_4_db=0
  
  if [ -f $tksuite_db_version_file ]
  then
    if grep -q "major=4" $tksuite_db_version_file
    then 
      echo "Database is TK-Suite 4 format"
      tksuite_4_db=1
    fi
  fi

  if [ $tksuite_4_db -ne 1 ]
  then
    if [ -f $tksuite_var_dir/dbf/call_history.db ] 
    then
      echo "call_history.db found. Assuming older TK-Suite 4 installation"
      tksuite_4_db=1

      echo "[schema]" >> $tksuite_db_version_file
      echo "major=4" >> $tksuite_db_version_file
    fi
  fi

  if [ $tksuite_4_db -ne 1 ]
  then
    echo "Starting TK-Suite 3 to TK-Suite 4 conversion"

    tksuite_var_dir_3=${tksuite_var_dir}_3
    mv $tksuite_var_dir $tksuite_var_dir_3
    mkdir $tksuite_var_dir
    mkdir $tksuite_var_dir/images
    mkdir $tksuite_var_dir/updates
    mkdir $tksuite_var_dir/files
    echo "copying files..."
    cp $tksuite_var_dir_3/files/* $tksuite_var_dir/files
    echo "copying extension images"
    cp $tksuite_var_dir_3/images/ext*.img $tksuite_var_dir/images
    echo "copying existing tksock.ini"
    cp $tksuite_var_dir_3/tksock.ini $tksuite_var_dir/tksock.ini
    echo "copying buttons.tpl"
    cp $tksuite_var_dir_3/buttons.tpl $tksuite_var_dir/buttons.tpl

    # Die update.xml hat sich in TK-Suite 4 geändert
    cp tksuite_server/update.xml.default $tksuite_var_dir/update.xml

    ./tools/convert_3_4 $tksuite_var_dir_3 $tksuite_var_dir
      
    echo "[schema]" >> $tksuite_db_version_file
    echo "major=4" >> $tksuite_db_version_file

  fi
fi


echo "Done! Got any errors? -> Please check root permissions"
